@@ -1,7 +1,7 @@
 Bootstrap <-
-function(x,p,h,nboot,correct)
+function(x,p,h,nboot)
 {
-    set.seed(12345)
+    #set.seed(12345)
     B <- LSM(x,p)
     n <- nrow(x)
     b <- B$coef 
@@ -15,12 +15,9 @@ function(x,p,h,nboot,correct)
         btem1 <- btem1 + OLS.AR(xs,p,0,0)$coef/nboot
     }
     bc <- 2*b-btem1
-
-    if( correct == "kilian")
+   
     bc <- adjust(b,bc,p)
-    if( correct == "ssf")
-    bc <- adjust2(bc,p)
-    
+      
     if(sum(b) != sum(bc))
     bc[p+1] <- mean(x)*(1-sum(bc[1:p]))
     
@@ -30,4 +27,3 @@ function(x,p,h,nboot,correct)
     f <- AR.Fore(x,bc,h)
 return(list(coef=bc,resid=e,forecast=f))
 }
-
