@@ -1,15 +1,11 @@
 Shaman.StineBT <-
-function(x,p,h,correct)
+function(x,p,h)
 {
 x <- as.matrix(x)
 n <- nrow(x)
 b <- LSMBT(x,p)$coef
 bc <- c(StineT(b,n,p),b[p+1],b[p+2])
-
-    if( correct == "kilian")
-    bc <- adjust(b,bc,p)
-    if( correct == "ssf")
-    bc <- adjust2(bc,p)
+bc <- adjust(b,bc,p)
 
 bc[(p+1):(p+2),] <- RE.LSMTB(x,p,bc)
 e <- RESIDT(x,bc)
@@ -18,4 +14,3 @@ if(h > 0)
 f <- ART.Fore(x,bc,h)
 return(list(coef=bc,resid=e,forecast=f))
 }
-
