@@ -1,11 +1,11 @@
 ShamanStine1T.PI <-
-function(x,p,h,nboot,prob,correct)
+function(x,p,h,nboot,prob)
 {
-set.seed(12345)
+#set.seed(12345)
 n <- nrow(x)
 
-BC <- Shaman.StineT(x,p,h,correct)
-BCB <- Shaman.StineBT(x,p,h,correct)
+BC <- Shaman.StineT(x,p,h)
+BCB <- Shaman.StineBT(x,p,h)
 
 bb <- BCB$coef
 eb <- sqrt( (n-p) / ( (n-p)-length(bb)))*BCB$resid
@@ -17,7 +17,7 @@ for(i in 1:nboot)
         index <- as.integer(runif(n-p, min=1, max=nrow(eb)))
         es <- eb[index,1]
         xs <- ysbT(x, bb, es)
-        bs <- Shaman.StineT(xs,p,h,correct)$coef
+        bs <- Shaman.StineT(xs,p,h)$coef
         fore[i,] <- ART.ForeB(xs,bs,h,ef,length(bs)-1)
     }
 
@@ -26,4 +26,3 @@ for( i in 1:h)
 Interval[i,] <- quantile(fore[,i],probs=prob)
 return(list(PI=Interval,forecast=BC$forecast))
 }
-
